@@ -55,7 +55,7 @@ def get_positional_features_gamma(positions, features, seq_len, stddev = None, s
     if not exists(start_mean):
         start_mean = seq_len / features
 
-    mean = torch.linspace(start_mean, seq_len, features)
+    mean = torch.linspace(start_mean, seq_len, features, device = positions.device)
     mean = mean[None, ...]
     concentration = (mean / stddev) ** 2
     rate = mean / stddev ** 2
@@ -319,10 +319,10 @@ class Enformer(nn.Module):
 
         # create final heads for human and mouse
 
-        self._heads = map_values(lambda features: nn.Sequential(
+        self._heads = nn.ModuleDict(map_values(lambda features: nn.Sequential(
             nn.Linear(twice_dim, features, 1),
             nn.Softplus()
-        ), output_heads)
+        ), output_heads))
 
     @property
     def trunk(self):
@@ -333,8 +333,17 @@ class Enformer(nn.Module):
         return self._heads
     
     def forward(self, x):
+        no_batch = (x.ndim == 1)
+        if no_batch:
+            x = rearrange(x, 'n -> () n')
+
         if x.dtype == torch.long:
             x = F.one_hot(x, num_classes = self.num_alphabet)
 
         x = self._trunk(x.float())
-        return map_values(lambda fn: fn(x), self._heads)
+        out = map_values(lambda fn: fn(x), self._heads)
+
+        if no_batch:
+            out = map_values(lambda t: rearrange(t, '() ... -> ...'), out)
+
+        return out
